{% load i18n %}

<li class="nav-item">
    <a class="nav-link" aria-current="page" href="{% url 'evictionsplit:index' %}">{% translate "Eviction Board" %}</a>
</li>

<li class="nav-item">
    <a class="nav-link" aria-current="page" href="{% url 'evictionsplit:list' %}">{% translate "Active evictions" %}</a>
</li>
